@@ -6,6 +6,7 @@ use std::sync::Arc;
 
 mod config;
 mod index;
+mod static_files;
 mod thumbnail;
 mod util;
 
@@ -24,8 +25,14 @@ fn rocket() -> anyhow::Result<Rocket<Build>> {
 
 	let rocket = rocket
 		.manage(config.clone())
-		.attach(Template::custom(|engines| engines.handlebars.set_strict_mode(true)))
-		.mount("/static", FileServer::new("public", FSOptions::Index))
+		.attach(Template::try_custom(|rocket_dyn_templates::Engines { handlebars: hbs, .. }| {
+			hbs.clear_templates(); // don't discover other templates
+			hbs.set_strict_mode(true);
+			hbs.register_template_string("base", std::include_str!("../templates/base.hbs"))?;
+			hbs.register_template_string("index", std::include_str!("../templates/index.html.hbs"))?;
+			Ok(())
+		}))
+		.mount("/static", routes![static_files::css, static_files::js])
 		.mount(
 			"/fs",
 			FileServer::new(&config.index_root, {
